(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     25433,        656]
NotebookOptionsPosition[     24422,        619]
NotebookOutlinePosition[     24861,        636]
CellTagsIndexPosition[     24818,        633]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Bacterial Computing", "Title"],

Cell["Using E. coli to Solve the Burnt Pancake Problem", "Subtitle"],

Cell["\<\
by Laurie J. Heyer, Jeffrey L. Poet, Marian L. Broderick, Phillip E. C. \
Compeau, James O. Dickson, and W. Lance Harden\
\>", "Text"],

Cell[TextData[{
 "Printed in ",
 ButtonBox["Math Horizons",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.maa.org/mathhorizons/"], None},
  ButtonNote->"http://www.maa.org/mathhorizons/"],
 ", a publication of the ",
 ButtonBox["Mathematical Association of America",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.maa.org/"], None},
  ButtonNote->"http://www.maa.org/"],
 ", Feb. 2010."
}], "Text"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " supplement by Bruce Torrence\nemail: btorrenc@rmc.edu"
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initializations",
 FontSize->12]], "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "reverse", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"reverse", "[", 
   RowBox[{"list_", ",", "s1_", ",", "s2_", ",", "burnt_"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"ReplacePart", "[", 
   RowBox[{"list", ",", 
    RowBox[{"Thread", "[", 
     RowBox[{"Rule", "[", 
      RowBox[{
       RowBox[{"Range", "[", 
        RowBox[{"s1", ",", "s2"}], "]"}], ",", 
       RowBox[{"Reverse", "@", 
        RowBox[{"Part", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Power", "[", 
            RowBox[{
             RowBox[{"-", "1"}], ",", 
             RowBox[{"Boole", "[", "burnt", "]"}]}], "]"}], "*", "list"}], 
          ",", 
          RowBox[{"s1", ";;", "s2"}]}], "]"}]}]}], "]"}], "]"}]}], 
   "]"}]}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "renderStack", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"renderStack", "[", 
   RowBox[{"list_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"SortBy", "[", 
   RowBox[{
    RowBox[{"MapIndexed", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Lighter", "@", 
          RowBox[{"Hue", "[", 
           RowBox[{
            RowBox[{"First", "@", "#2"}], "/", "n"}], "]"}]}], ",", 
         RowBox[{"EdgeForm", "[", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Sign", "[", "#1", "]"}], "\[Equal]", 
             RowBox[{"-", "1"}]}], ",", "Thick", ",", "Thin"}], "]"}], "]"}], 
         ",", 
         RowBox[{"Polygon", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"First", "@", "#2"}]}], ",", 
              RowBox[{
               RowBox[{"Abs", "@", "#1"}], "-", "1"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"First", "@", "#2"}], ",", 
              RowBox[{
               RowBox[{"Abs", "@", "#1"}], "-", "1"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"First", "@", "#2"}], ",", 
              RowBox[{"Abs", "@", "#1"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"First", "@", "#2"}]}], ",", 
              RowBox[{"Abs", "@", "#1"}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
       "&"}], ",", 
      RowBox[{
       RowBox[{"Sign", "[", 
        RowBox[{"SortBy", "[", 
         RowBox[{"list", ",", "Abs"}], "]"}], "]"}], "*", 
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Position", "[", 
           RowBox[{
            RowBox[{"Reverse", "@", 
             RowBox[{"Abs", "@", "list"}]}], ",", "#"}], "]"}], "&"}], "/@", 
         RowBox[{"Range", "[", "n", "]"}]}], "]"}]}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"Cases", "[", 
      RowBox[{"#", ",", "Large", ",", "Infinity"}], "]"}], "&"}]}], 
   "]"}]}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["The pancake flipping demonstration", "Section",
 FontSize->12],

Cell["Cakes with a solid border are burnt-side-up.", "Text"],

Cell["\<\
Click on the left side of the stack to set the top spatula, and click on \
right half of the stack to set the bottom spatula, then push the \"flip\" \
button to reverse the cakes between the spatulas. Repeat until the stack is \
sorted with all cakes burnt-side-down.\
\>", "Text"],

Cell["\<\
In \"one spatula\" mode, all cakes above the green spatula will be flipped.\
\>", "Text"],

Cell["\<\
Push the \"zip line\" button twice to set up the stack to be used as a \
zip-line problem.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DynamicModule", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"list", ",", 
        RowBox[{"s1", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "n"}], "-", "1"}], ",", "n"}], "}"}]}], ",", 
        RowBox[{"s2", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"n", "+", "1"}], ",", "1"}], "}"}]}], ",", 
        RowBox[{"flips", "=", "0"}], ",", "currentNewList"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"list", "=", 
        RowBox[{"If", "[", 
         RowBox[{"burnt", ",", 
          RowBox[{
           RowBox[{"RandomChoice", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "n"}], "]"}], "*", 
           
           RowBox[{"RandomSample", "[", 
            RowBox[{"Range", "[", "n", "]"}], "]"}]}], ",", 
          RowBox[{"RandomSample", "[", 
           RowBox[{"Range", "[", "n", "]"}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"currentNewList", "=", "list"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", "two"}], ",", 
         RowBox[{"s1", "=", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "n"}], "-", "1"}], ",", "n"}], "}"}]}]}], "]"}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Column", "[", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Row", "[", 
            RowBox[{
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Button", "[", 
                RowBox[{"\"\<flip\>\"", ",", 
                 RowBox[{
                  RowBox[{"list", "=", 
                   RowBox[{"reverse", "[", 
                    RowBox[{"list", ",", 
                    RowBox[{"n", "+", "1", "-", 
                    RowBox[{"Last", "@", "s1"}]}], ",", 
                    RowBox[{"n", "-", 
                    RowBox[{"Last", "@", "s2"}]}], ",", "burnt"}], "]"}]}], 
                  ";", 
                  RowBox[{"flips", "+=", "1"}]}]}], "]"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"Dynamic", "@", 
                RowBox[{"Text", "[", 
                 RowBox[{
                  RowBox[{"ToString", "[", "flips", "]"}], "~~", 
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"flips", "\[NotEqual]", "1"}], ",", 
                    "\"\< flips\>\"", ",", "\"\< flip\>\""}], "]"}]}], 
                 "]"}]}]}], "\[IndentingNewLine]", "}"}], ",", 
             "\"\<     \>\""}], "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"EventHandler", "[", 
            RowBox[{
             RowBox[{"Dynamic", "@", 
              RowBox[{"Graphics", "[", 
               RowBox[{
                RowBox[{"{", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Lighter", "[", 
                    RowBox[{"Gray", ",", ".8"}], "]"}], ",", 
                    RowBox[{"Polygon", "[", 
                    RowBox[{"{", 
                    RowBox[{"s1", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "+", "1"}], ",", 
                    RowBox[{"Last", "@", "s1"}]}], "}"}], ",", "s2", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "n"}], "-", "1"}], ",", 
                    RowBox[{"Last", "@", "s2"}]}], "}"}]}], "}"}], "]"}]}], 
                   "}"}], ",", "\[IndentingNewLine]", 
                  RowBox[{"If", "[", 
                   RowBox[{"two", ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"Text", "[", 
                    RowBox[{
                    "\"\<top spatula \[RightPointer]\>\"", ",", "s1", ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "0"}], "}"}]}], "]"}], ",", "Red", ",", 
                    "10"}], "]"}], ",", 
                    RowBox[{"{", "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
                  RowBox[{"If", "[", 
                   RowBox[{"two", ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"Text", "[", 
                    RowBox[{
                    "\"\<\[LeftPointer] bottom spatula\>\"", ",", "s2", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
                    "Green", ",", "10"}], "]"}], ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"Text", "[", 
                    RowBox[{
                    "\"\<\[LeftPointer] spatula\>\"", ",", "s2", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
                    "Green", ",", "10"}], "]"}]}], "]"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"renderStack", "[", 
                   RowBox[{"list", ",", "n"}], "]"}]}], "}"}], ",", 
                RowBox[{"PlotRange", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "n"}], "-", "8"}], ",", 
                    RowBox[{"n", "+", "8"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"n", "+", "1"}]}], "}"}]}], "}"}]}], ",", 
                RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"\"\<MouseDown\>\"", "\[RuleDelayed]", 
              RowBox[{"(", "\[IndentingNewLine]", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"two", "&&", 
                  RowBox[{
                   RowBox[{"First", "@", 
                    RowBox[{"MousePosition", "[", "\"\<Graphics\>\"", "]"}]}],
                    "<", "0"}]}], ",", "\[IndentingNewLine]", 
                 RowBox[{"s1", "=", 
                  RowBox[{"First", "@", 
                   RowBox[{"Nearest", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "n"}], "-", "1"}], ",", "#"}], "}"}], "&"}], 
                    "/@", 
                    RowBox[{"Range", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Last", "@", "s2"}], "+", "1"}], ",", "n"}], 
                    "]"}]}], ",", 
                    RowBox[{"MousePosition", "[", "\"\<Graphics\>\"", "]"}]}],
                     "]"}]}]}], ",", "\[IndentingNewLine]", 
                 RowBox[{"s2", "=", 
                  RowBox[{"First", "@", 
                   RowBox[{"Nearest", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"n", "+", "1"}], ",", "#"}], "}"}], "&"}], "/@", 
                    RowBox[{"Range", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{
                    RowBox[{"Last", "@", "s1"}], "-", "1"}]}], "]"}]}], ",", 
                    RowBox[{"MousePosition", "[", "\"\<Graphics\>\"", "]"}]}],
                     "]"}]}]}]}], "\[IndentingNewLine]", "]"}], ")"}]}]}], 
            "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Row", "[", 
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Button", "[", 
               RowBox[{"\"\<start over with same stack\>\"", ",", 
                RowBox[{
                 RowBox[{"list", "=", "currentNewList"}], ";", 
                 RowBox[{"flips", "=", "0"}]}]}], "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Button", "[", 
               RowBox[{"\"\<new stack\>\"", ",", 
                RowBox[{
                 RowBox[{"list", "=", 
                  RowBox[{"If", "[", 
                   RowBox[{"burnt", ",", 
                    RowBox[{
                    RowBox[{"RandomChoice", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "n"}], "]"}], 
                    "*", 
                    RowBox[{"RandomSample", "[", 
                    RowBox[{"Range", "[", "n", "]"}], "]"}]}], ",", 
                    RowBox[{"RandomSample", "[", 
                    RowBox[{"Range", "[", "n", "]"}], "]"}]}], "]"}]}], ";", 
                 RowBox[{"currentNewList", "=", "list"}], ";", 
                 RowBox[{"flips", "=", "0"}]}]}], "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Button", "[", 
               RowBox[{"\"\<Zip-line problem\>\"", ",", 
                RowBox[{
                 RowBox[{"n", "=", "6"}], ";", 
                 RowBox[{"burnt", "=", "True"}], ";", 
                 RowBox[{"two", "=", "True"}], ";", 
                 RowBox[{"flips", "=", "0"}], ";", 
                 RowBox[{"list", "=", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"-", "2"}], ",", "3", ",", "5", ",", 
                    RowBox[{"-", "1"}], ",", "6", ",", "4"}], "}"}]}], ";", 
                 RowBox[{"currentNewList", "=", "list"}]}]}], "]"}]}], 
             "\[IndentingNewLine]", "}"}], "]"}]}], "\[IndentingNewLine]", 
          "}"}], ",", 
         RowBox[{"Alignment", "\[Rule]", "Center"}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n", ",", "6", ",", "\"\<number of pancakes\>\""}], "}"}], ",", 
      RowBox[{"Range", "[", 
       RowBox[{"2", ",", "8"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"burnt", ",", "False", ",", "\"\<allow burnt pancakes\>\""}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"two", ",", "False", ",", "\"\<allow two spatulas\>\""}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
    RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`burnt$$ = True, $CellContext`n$$ = 
    6, $CellContext`two$$ = True, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`n$$], 6, "number of pancakes"}, {2, 3, 4, 5, 6, 7, 
      8}}, {{
       Hold[$CellContext`burnt$$], False, "allow burnt pancakes"}, {
      True, False}}, {{
       Hold[$CellContext`two$$], False, "allow two spatulas"}, {
      True, False}}}, Typeset`size$$ = {600., {123.53125, 131.46875}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`n$30006$$ = 0, $CellContext`burnt$30007$$ = 
    False, $CellContext`two$30008$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`burnt$$ = False, $CellContext`n$$ = 
        6, $CellContext`two$$ = False}, "ControllerVariables" :> {
        Hold[$CellContext`n$$, $CellContext`n$30006$$, 0], 
        Hold[$CellContext`burnt$$, $CellContext`burnt$30007$$, False], 
        Hold[$CellContext`two$$, $CellContext`two$30008$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      DynamicModule[{$CellContext`list, $CellContext`s1 = {-$CellContext`n$$ - 
           1, $CellContext`n$$}, $CellContext`s2 = {$CellContext`n$$ + 1, 
           1}, $CellContext`flips = 
         0, $CellContext`currentNewList}, $CellContext`list = 
         If[$CellContext`burnt$$, RandomChoice[{-1, 1}, $CellContext`n$$] 
           RandomSample[
             Range[$CellContext`n$$]], 
           RandomSample[
            
            Range[$CellContext`n$$]]]; $CellContext`currentNewList = \
$CellContext`list; If[
          Not[$CellContext`two$$], $CellContext`s1 = {-$CellContext`n$$ - 
            1, $CellContext`n$$}]; Column[{
           Row[{
             Button[
             "flip", $CellContext`list = \
$CellContext`reverse[$CellContext`list, $CellContext`n$$ + 1 - 
                 Last[$CellContext`s1], $CellContext`n$$ - 
                 Last[$CellContext`s2], $CellContext`burnt$$]; 
              AddTo[$CellContext`flips, 1]], 
             Dynamic[
              Text[
               StringExpression[
                ToString[$CellContext`flips], 
                If[$CellContext`flips != 1, " flips", " flip"]]]]}, "     "], 
           
           EventHandler[
            Dynamic[
             Graphics[{{
                Lighter[Graphics`Colors`Gray, 0.8], 
                Polygon[{$CellContext`s1, {$CellContext`n$$ + 1, 
                   
                   Last[$CellContext`s1]}, $CellContext`s2, \
{-$CellContext`n$$ - 1, 
                   Last[$CellContext`s2]}}]}, 
               If[$CellContext`two$$, 
                Style[
                 Text["top spatula \[RightPointer]", $CellContext`s1, {1, 0}],
                  Graphics`Colors`Red, 10], {}], 
               If[$CellContext`two$$, 
                Style[
                 Text[
                 "\[LeftPointer] bottom spatula", $CellContext`s2, {-1, 0}], 
                 Graphics`Colors`Green, 10], 
                Style[
                 Text["\[LeftPointer] spatula", $CellContext`s2, {-1, 0}], 
                 Graphics`Colors`Green, 10]], 
               $CellContext`renderStack[$CellContext`list, $CellContext`n$$]},
               PlotRange -> {{-$CellContext`n$$ - 8, $CellContext`n$$ + 
                 8}, {-1, $CellContext`n$$ + 1}}, ImageSize -> 400]], 
            "MouseDown" :> If[
              And[$CellContext`two$$, First[
                 MousePosition["Graphics"]] < 0], $CellContext`s1 = First[
                Nearest[
                 Map[{-$CellContext`n$$ - 1, #}& , 
                  Range[Last[$CellContext`s2] + 1, $CellContext`n$$]], 
                 MousePosition["Graphics"]]], $CellContext`s2 = First[
                Nearest[
                 Map[{$CellContext`n$$ + 1, #}& , 
                  Range[0, Last[$CellContext`s1] - 1]], 
                 MousePosition["Graphics"]]]]], 
           Row[{
             Button[
             "start over with same stack", $CellContext`list = \
$CellContext`currentNewList; $CellContext`flips = 0], 
             Button[
             "new stack", $CellContext`list = 
               If[$CellContext`burnt$$, 
                 RandomChoice[{-1, 1}, $CellContext`n$$] RandomSample[
                   Range[$CellContext`n$$]], 
                 RandomSample[
                  
                  Range[$CellContext`n$$]]]; $CellContext`currentNewList = \
$CellContext`list; $CellContext`flips = 0], 
             Button[
             "Zip-line problem", $CellContext`n$$ = 6; $CellContext`burnt$$ = 
               True; $CellContext`two$$ = True; $CellContext`flips = 
               0; $CellContext`list = {-2, 3, 5, -1, 6, 
                4}; $CellContext`currentNewList = $CellContext`list]}]}, 
          Alignment -> Center]], 
      "Specifications" :> {{{$CellContext`n$$, 6, "number of pancakes"}, {2, 
         3, 4, 5, 6, 7, 
         8}}, {{$CellContext`burnt$$, False, "allow burnt pancakes"}, {
         True, False}}, {{$CellContext`two$$, False, "allow two spatulas"}, {
         True, False}}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{662., {218.03125, 225.96875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`reverse[
         Pattern[$CellContext`list, 
          Blank[]], 
         Pattern[$CellContext`s1, 
          Blank[]], 
         Pattern[$CellContext`s2, 
          Blank[]], 
         Pattern[$CellContext`burnt, 
          Blank[]]] := ReplacePart[$CellContext`list, 
         Thread[Range[$CellContext`s1, $CellContext`s2] -> Reverse[
            Part[(-1)^Boole[$CellContext`burnt] $CellContext`list, 
             Span[$CellContext`s1, $CellContext`s2]]]]], $CellContext`reverse[
        
         Pattern[$CellContext`list, 
          Blank[]], {
          Pattern[$CellContext`a, 
           Blank[]], 
          Pattern[$CellContext`b, 
           
           Blank[]]}] := $CellContext`reverse[$CellContext`list, \
$CellContext`a, $CellContext`b, True], Graphics`Colors`Gray = 
       RGBColor[0.752907, 0.752907, 0.752907], 
       TagSet[Graphics`Colors`Gray, 
        MessageName[Graphics`Colors`Gray, "usage"], 
        "Gray is a color given in the RGBColor system."], Graphics`Colors`Red = 
       RGBColor[1., 0., 0.], 
       TagSet[Graphics`Colors`Red, 
        MessageName[Graphics`Colors`Red, "usage"], 
        "Red is a color given in the RGBColor system."], 
       Graphics`Colors`Green = RGBColor[0., 1., 0.], 
       TagSet[Graphics`Colors`Green, 
        MessageName[Graphics`Colors`Green, "usage"], 
        "Green is a color given in the RGBColor system."], \
$CellContext`renderStack[
         Pattern[$CellContext`list, 
          Blank[]], 
         Pattern[$CellContext`n, 
          Blank[]]] := SortBy[
         MapIndexed[{
           Lighter[
            Hue[First[#2]/$CellContext`n]], 
           EdgeForm[
            If[Sign[#] == -1, Thick, Thin]], 
           Polygon[{{-First[#2], Abs[#] - 1}, {
              First[#2], Abs[#] - 1}, {
              First[#2], 
              Abs[#]}, {-First[#2], 
              Abs[#]}}]}& , Sign[
            SortBy[$CellContext`list, Abs]] Flatten[
            Map[Position[
              Reverse[
               Abs[$CellContext`list]], #]& , 
             Range[$CellContext`n]]]], Cases[#, Large, Infinity]& ]}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output"]
}, {2}]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{943, 743},
WindowMargins->{{209, Automatic}, {Automatic, 9}},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.5, 1.5 Inherited],
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 36, 0, 114, "Title"],
Cell[606, 24, 68, 0, 69, "Subtitle"],
Cell[677, 26, 144, 3, 62, "Text"],
Cell[824, 31, 429, 14, 39, "Text"],
Cell[1256, 47, 134, 4, 62, "Text"],
Cell[CellGroupData[{
Cell[1415, 55, 69, 1, 88, "Section"],
Cell[1487, 58, 815, 24, 301, "Input"],
Cell[2305, 84, 2187, 63, 559, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[4529, 152, 68, 1, 41, "Section"],
Cell[4600, 155, 60, 0, 39, "Text"],
Cell[4663, 157, 291, 5, 84, "Text"],
Cell[4957, 164, 99, 2, 39, "Text"],
Cell[5059, 168, 114, 3, 39, "Text"],
Cell[CellGroupData[{
Cell[5198, 175, 11056, 260, 3708, "Input"],
Cell[16257, 437, 8128, 177, 468, "Output"]
}, {2}]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
